Learn R Programming

attachment (version 1.1.0)

att_from_examples: Get all packages called in examples from R files

Description

Get all packages called in examples from R files

Usage

att_from_examples(dir.r = "R", encoding = getOption("encoding"))

Value

Character vector of packages called with library or require.

Arguments

dir.r

path to directory with R scripts.

encoding

Encoding passed to readLines() when reading source files. Defaults to getOption("encoding") so the system locale is respected, matching att_from_rscript().

Examples

Run this code
dummypackage <- system.file("dummypackage",package = "attachment")

# browseURL(dummypackage)
att_from_examples(dir.r = file.path(dummypackage,"R"))

Run the code above in your browser using DataLab